#!/usr/bin/env python3
#
# Copyright 2024 ROBOTIS CO., LTD.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Author: Wonho Yoon, Sungho Woo

from launch import LaunchDescription
from launch.actions import DeclareLaunchArgument
from launch.substitutions import LaunchConfiguration
from launch_ros.actions import Node


def generate_launch_description():
    ld = LaunchDescription()

    # The default DB port for moveit (not default MongoDB port to avoid potential conflicts)
    ld.add_action(DeclareLaunchArgument('moveit_warehouse_port', default_value='33829'))

    # The default DB host for moveit
    ld.add_action(
        DeclareLaunchArgument('moveit_warehouse_host', default_value='localhost')
    )

    # Load warehouse parameters
    db_parameters = [
        {
            'overwrite': False,
            'warehouse_port': LaunchConfiguration('moveit_warehouse_port'),
            'warehouse_host': LaunchConfiguration('moveit_warehouse_host'),
            'warehouse_exec': 'mongod',
            'warehouse_plugin': 'warehouse_ros_mongo::MongoDatabaseConnection',
        },
    ]

    # Run the DB server
    db_node = Node(
        package='warehouse_ros_mongo',
        executable='mongo_wrapper_ros.py',
        parameters=db_parameters,
    )
    ld.add_action(db_node)

    return ld
